#!/usr/bin/env python3

import sys
import re
from math import sqrt,log10
from astropy.time import Time 

def apc(filename, dataset):
  datasetstr = filename

  f = open(filename)
  print("# JD(TDB,nolite) & V [mag] & sigma [mag] & dataset & note")

  f2 = open("jpl.tmp", "w")

  i=0
  for line in f.readlines():
    l = line.split()
    if re.match(r"#.*", line):
      continue
    if re.match(r"ZERO TIME.*", line):
      zero_time = float(l[2])
    if re.match(r"ZERO MAG.*", line):
      zero_mag = float(l[2])
    if re.match(r".*Earth.*", line):
      x_se = float(l[1])
      y_se = float(l[2])
      z_se = float(l[3])
    if re.match(r".*object*", line):
      x_sa = float(l[1])
      y_sa = float(l[2])
      z_sa = float(l[3])
      x_ea = x_sa-x_se
      y_ea = y_sa-y_se
      z_ea = z_sa-z_se
      d1 = sqrt(x_sa**2+y_sa**2+z_sa**2)
      d2 = sqrt(x_ea**2+y_ea**2+z_ea**2)
      print("# d1 = ", d1, " au")
      print("# d2 = ", d2, " au")
    if re.match(r"======.*", line):
      i=0
    if re.match("DATA:.*", line):
      i=1
      continue
    if i==0:
      continue

    jd = float(l[0])/24.0 + zero_time
    V0 = float(l[1]) + zero_mag
    V = V0 + 5.*log10(d1) + 5.*log10(d2)  # reduced->unreduced
    sigma = 0.01

    t1 = Time(jd, scale='utc', format='jd')
    t2 = t1.tdb

    print("%.8f  %.6f  %.6f  %d  %s" % (t2.jd, V, sigma, dataset, datasetstr))
    f2.write("'%.8f'\n" % (t1.jd))
    
  f.close()
  f2.close()

def main():
  j = 0
  for filename in sys.argv[1:]:
    j += 1
    apc(filename, j)

if __name__ == "__main__":
  main()

