#!/usr/bin/env python3

import sys
import subprocess
import numpy as np
#from astropy.io import fits
from astropy.time import Time

def jd_bessel(jd):
    return 1900.0 + (jd - 2415020.31352) / 365.242198781

def bessel_jd(bessel):
    return (bessel - 1900.0) * 365.242198781 + 2415020.31352

c = 2.99792458e8
au = 1.49597870700e11
day = 86400.

def main():

    f = open("Lc_V.dat", "w")
    f.write("# JD (TDB, no lite) & flux_V [mag] & sigma [mag] & dataset & Besselian year (UTC, no lite)\n")

    f2 = open("jpl.tmp", "w")

    dataset = 0
    for line in sys.stdin:
        if line[0:1] == '#': 
            continue
        l = line.split()
        if len(l) == 2:
            dataset += 1
            continue

        jd_lite = float(l[0])
        flux = float(l[1])
        x = float(l[5])
        y = float(l[6])
        z = float(l[7])

        d = np.sqrt(x**2+y**2+z**2)
        lite = -(d*au/c)/day
        jd_nolite = jd_lite - lite

        t1 = Time(jd_nolite, format="jd", scale="utc")
        t2 = t1.tdb

        bessel = jd_bessel(t1.jd)

        calibration_flux = 1.0
        mag = -2.5*np.log10(flux/calibration_flux)
        mag += 10.0
        sigma_mag = 0.01
#        sigma_mag = mag + 2.5*np.log10((flux+sigma)/calibration_flux)

        f.write("%.8f  %12.8f  %.8f  %d  %.8f  # %f %f %f\n" % (t2.jd, mag, sigma_mag, dataset, bessel, jd_lite, jd_nolite, lite))
        f2.write("'%.8f'\n" % (t1.jd))

    f.close()
    f2.close()

if __name__ == "__main__":
    main()


